==> download_v2.3.661.zip: download/lang/en.php <==
<?php
######################################################################
# Authors: Franz-Peter Glawar <office@glawar.at>, 2014
#
# This php contains the english language entries
#
#
# (c) www.glawar.at
#
######################################################################
####  History
#---------------------------------------------------------------------
# v2014-11-28 FPG created the script
# v2014-12-02 FPG added new entries for english
######################################################################
####  Variables that should be adapted if necessary
####------------------------------------------------------------------
######################################################################
####  Variables that should not be changed
####------------------------------------------------------------------
######################################################################


$lang = array(
    "listfiles"=> "Files",
    "addnewfile" => "Add file",
    "adduser" => "Add User",
    "showusers"=> "Users",
    "changepassword" => "Change Password",
    "logout" => "Logout",
    "accountdeactivated"=> "Your account has been deactivated, please contact your system administrator",
    "userpwdwrong" => "Either username or password is wrong, please try again",
    "username" => "Username",
    "password"=> "Password",
    "login" => "Login",
    "newpassword" => "new password",
    "retypepwd"=> "retype new password",
    "filename" => "Filename",
    "filedescription" => "Filedescription",
    "upload"=> "Upload",
    "updateuser" => "Update user",
    "lastname" => "Lastname",
    "firstname"=> "Firstname",
    "email" => "Email",
    "active" => "Account is active",
    "allowedtoaddfiles"=> "User is allowed to add files",
    "group" => "Group",
    "nodbaccess"=> "No Database Access",
    "causedbyselect" => "Caused by select ",
    "nouserupdate" => "User could not be updated!",
    "nousercreated"=> "User could not be created!",
    "passwordminimumlength" => "Password must be minimum length ",
    "errorbindinginput" => "Binding Input-Params of SQL-Statement had an error: ",
    "manageusernotallfieldsfilledout" => "User could not be added/modified because you have to fill out all the necessary fields",
    "errorbindingoutput" => "Binding Output-Params of SQL-Statement had an error: ",
    "nonewfilenofilename" => "No new file entry created: No filename specified",
    "filenotsaved"=> "File could not be saved: ",
    "filenotadded" => "File could not be added",
    "nonewfilenofile" => "No new file entry created: No file specified",
    "changepwdfillout"=> "Changing Password: You have to fill out all the given fields",
    "passwordnotchanged" => "Password could not be changed",
    "passwordsnotmatch" => "Your passwords do not match",
    "created"=> "crated",
    "modified" => "Modified",
    "changepermission" => "Change Permissions",
    "save"=> "Save",
    "action" => "Action",
    "view" => "View",
    "filesize" => "Filesize",
    "date" => "Date",
    "logtoscreen" => "Log to screen",
    "updatedon" => "update done",
    "availablefile" => "Available files",
    "allowedtoaddfiles2"=> "add files",
    "active2" => "active",
    "change" => "change",
    "user" => "user",
    "usernameminimumlength" => "Username must be minimum length ",
    "userhaschangedpwd" => "user has changed his password",
    "contactSysadmin" => "A technical problem occured. Please contact your system administrator",
    "noAccessMySQL" => "No Access to MySQL database",
    "notinstalledbasenecessary" => "You have to install DownloadManager first",
    "installationdone" => "Installation done",
    "installationof" => "Installation of",
    "providedatabase" => "You have to provide a database with username and password. E. g.:",
    "doInstallation" => "Do Installation",
    "MySQLDatabase" => "MySQL-Database",
    "creatingdatabasestructure" => "creating database structure",
    "insertingbasedata" => "inserting base data",
    "creatingversioncheck" => "creating version check",
    "creatingconfigentries" => "creating config entries",
    "dbalreadymin" => "database already has minimum version",
    "updatingfromversion1" => "We do a database update",
    "passwordforgotten" => "Passwort forgotten",
    "resetpassword" => "Reset password",
    "sendresetpwd" => "Send reset link by email",
    "contact" => "Contact",
    "sendemail" => "Send Email",
    "emailcontext" => "Your email message",
    "emailheader" => "Contact",
    "resetPwdEmailHeader" => "Reset password",
    "resetPWDEmail" => "You have forgotten your password and therefore you have ordered to reset your existing password.",
    "resetPWDEmail2" => "Please click on the next link to reset your password and to define a new one.",
    "back" => "back",
    "myData" => "MyData",
    "changemydata" => "Save",
    "changemydatafillout"=> "Your Data: You have to fill out all the given fields",
    "showgroups" => "Groups",
    "addgroup" => "Add group",
    "youremail" => "Your E-Mail",
    "updategroup" => "Update Group",
    "groupmembers" => "Member of groups",
    "notenoughpermission" => "You have not the necessary permission to execute this menu.",
    "newupload" => "New file has been uploaded"
);
?>

==> download_v3.0.681.zip: download/lang/en.php <==
<?php
######################################################################
# Authors: Franz-Peter Glawar <office@glawar.at>, 2014
#
# This php contains the english language entries
#
#
# (c) www.glawar.at
#
######################################################################
####  History
#---------------------------------------------------------------------
# v2014-11-28 FPG created the script
# v2014-12-02 FPG added new entries for english
######################################################################
####  Variables that should be adapted if necessary
####------------------------------------------------------------------
######################################################################
####  Variables that should not be changed
####------------------------------------------------------------------
######################################################################


$lang = array(
    "listfiles"=> "Files",
    "addnewfile" => "Add file",
    "adduser" => "Add User",
    "showusers"=> "Users",
    "changepassword" => "Change Password",
    "logout" => "Logout",
    "accountdeactivated"=> "Your account has been deactivated, please contact your system administrator",
    "userpwdwrong" => "Either username or password is wrong, please try again",
    "username" => "Username",
    "password"=> "Password",
    "login" => "Login",
    "newpassword" => "new password",
    "retypepwd"=> "retype new password",
    "filename" => "Filename",
    "filedescription" => "Filedescription",
    "upload"=> "Upload",
    "updateuser" => "Update user",
    "lastname" => "Lastname",
    "firstname"=> "Firstname",
    "email" => "Email",
    "active" => "Account is active",
    "allowedtoaddfiles"=> "User is allowed to add files",
    "group" => "Group",
    "nodbaccess"=> "No Database Access",
    "causedbyselect" => "Caused by select ",
    "nouserupdate" => "User could not be updated!",
    "nousercreated"=> "User could not be created!",
    "passwordminimumlength" => "Password must be minimum length ",
    "errorbindinginput" => "Binding Input-Params of SQL-Statement had an error: ",
    "manageusernotallfieldsfilledout" => "User could not be added/modified because you have to fill out all the necessary fields",
    "errorbindingoutput" => "Binding Output-Params of SQL-Statement had an error: ",
    "nonewfilenofilename" => "No new file entry created: No filename specified",
    "filenotsaved"=> "File could not be saved: ",
    "filenotadded" => "File could not be added",
    "nonewfilenofile" => "No new file entry created: No file specified",
    "changepwdfillout"=> "Changing Password: You have to fill out all the given fields",
    "passwordnotchanged" => "Password could not be changed",
    "passwordsnotmatch" => "Your passwords do not match",
    "created"=> "crated",
    "modified" => "Modified",
    "changepermission" => "Change Permissions",
    "save"=> "Save",
    "action" => "Action",
    "view" => "View",
    "filesize" => "Filesize",
    "date" => "Date",
    "logtoscreen" => "Log to screen",
    "updatedon" => "update done",
    "availablefile" => "Available files",
    "allowedtoaddfiles2"=> "add files",
    "active2" => "active",
    "change" => "change",
    "user" => "user",
    "usernameminimumlength" => "Username must be minimum length ",
    "userhaschangedpwd" => "user has changed his password",
    "contactSysadmin" => "A technical problem occured. Please contact your system administrator",
    "noAccessMySQL" => "No Access to MySQL database",
    "notinstalledbasenecessary" => "You have to install DownloadManager first",
    "installationdone" => "Installation done",
    "installationof" => "Installation of",
    "providedatabase" => "You have to provide a database with username and password. E. g.:",
    "doInstallation" => "Do Installation",
    "MySQLDatabase" => "MySQL-Database",
    "creatingdatabasestructure" => "creating database structure",
    "insertingbasedata" => "inserting base data",
    "creatingversioncheck" => "creating version check",
    "creatingconfigentries" => "creating config entries",
    "dbalreadymin" => "database already has minimum version",
    "updatingfromversion1" => "We do a database update",
    "passwordforgotten" => "Passwort forgotten",
    "resetpassword" => "Reset password",
    "sendresetpwd" => "Send reset link by email",
    "contact" => "Contact",
    "sendemail" => "Send Email",
    "emailcontext" => "Your email message",
    "emailheader" => "Contact",
    "resetPwdEmailHeader" => "Reset password",
    "resetPWDEmail" => "You have forgotten your password and therefore you have ordered to reset your existing password.",
    "resetPWDEmail2" => "Please click on the next link to reset your password and to define a new one.",
    "back" => "back",
    "myData" => "MyData",
    "changemydata" => "Save",
    "changemydatafillout"=> "Your Data: You have to fill out all the given fields",
    "showgroups" => "Groups",
    "addgroup" => "Add group",
    "youremail" => "Your E-Mail",
    "updategroup" => "Update Group",
    "groupmembers" => "Member of groups",
    "notenoughpermission" => "You have not the necessary permission to execute this menu.",
    "newupload" => "New file has been uploaded",
    "dbtableprefix" => "Database table prefix",
    "nochangeindemo" => "You cannot change data concerning the administrator in demo mode",
    "language" => "Language",
    "nopermission" => "You are not allowed to download this file"
);
?>
